@@ -30,16 +30,16 @@ def download_file(url, save_path):
     :param save_path: 保存文件名
     :return:
     """
-    try:
-        content = request.urlopen(url)
+    res = requests.get(url)
+    if res.status_code == 200:
         basename = os.path.dirname(save_path)
         if not os.path.exists(basename):
             os.makedirs(basename)
         with open(save_path, 'wb') as f:
-            f.write(content.read())
+            f.write(res.content)
         return 'ok'
-    except Exception as e:
-        return e
+    else:
+        raise Exception('文件下载失败:%s:%s' % (res.status_code, url))
 
 
 def execute(command, cwd='/', login=False):
